elephant.kernels.ExponentialKernel
==================================

.. currentmodule:: elephant.kernels

.. autoclass:: ExponentialKernel
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ExponentialKernel.__init__
      ~ExponentialKernel.boundary_enclosing_area_fraction
      ~ExponentialKernel.cdf
      ~ExponentialKernel.icdf
      ~ExponentialKernel.is_symmetric
      ~ExponentialKernel.median_index
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ExponentialKernel.min_cutoff
   
   